// -*- mode: C++ -*-

// AUTOGENERATED BY glean_parser.  DO NOT EDIT.

/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "mozilla/glean/bindings/GleanJSMetricsLookup.h"

#include "mozilla/PerfectHash.h"
#include "mozilla/Maybe.h"
#include "mozilla/glean/bindings/MetricTypes.h"
#include "mozilla/glean/fog_ffi_generated.h"
#include "nsString.h"

#define GLEAN_INDEX_BITS (32)
#define GLEAN_TYPE_BITS (5)
#define GLEAN_ID_BITS (27)
#define GLEAN_TYPE_ID(id) ((id) >> GLEAN_ID_BITS)
#define GLEAN_METRIC_ID(id) ((id) & ((1ULL << GLEAN_ID_BITS) - 1))
#define GLEAN_OFFSET(entry) (entry & ((1ULL << GLEAN_INDEX_BITS) - 1))

namespace mozilla::glean {

// The category lookup table's entry type
using category_entry_t = uint32_t;
// The metric lookup table's entry type
// This is a bitpacked type with 32 bits available to index into
// the string table, 5 bits available to signify the metric type,
// and the remaining 27 bits devoted to 2 "signal"
// bits to signify important characteristics (metric's a labeled metric's
// submetric, metric's been registered at runtime) and 25 bits
// for built-in metric ids.
// Gives room for 33554432 of each combination of
// characteristics (which hopefully will prove to be enough).
using metric_entry_t = uint64_t;

static_assert(GLEAN_INDEX_BITS + GLEAN_TYPE_BITS + GLEAN_ID_BITS == sizeof(metric_entry_t) * 8, "Index, Type, and ID bits need to fit into a metric_entry_t");
static_assert(GLEAN_TYPE_BITS + GLEAN_ID_BITS <= sizeof(uint32_t) * 8, "Metric Types and IDs need to fit into at most 32 bits");
static_assert(48 < UINT32_MAX, "Too many metric categories generated.");
static_assert(244 < 33554432, "Too many metrics generated. Need room for 2 signal bits.");
static_assert(19 < 32, "Too many different metric types.");

already_AddRefed<nsISupports> NewMetricFromId(uint32_t id) {
  uint32_t typeId = GLEAN_TYPE_ID(id);
  uint32_t metricId = GLEAN_METRIC_ID(id);

  switch (typeId) {
    case 1: /* string_list */
    {
      return MakeAndAddRef<GleanStringList>(metricId);
    }
    case 2: /* datetime */
    {
      return MakeAndAddRef<GleanDatetime>(metricId);
    }
    case 3: /* uuid */
    {
      return MakeAndAddRef<GleanUuid>(metricId);
    }
    case 4: /* boolean */
    {
      return MakeAndAddRef<GleanBoolean>(metricId);
    }
    case 5: /* string */
    {
      return MakeAndAddRef<GleanString>(metricId);
    }
    case 6: /* quantity */
    {
      return MakeAndAddRef<GleanQuantity>(metricId);
    }
    case 7: /* event */
    {
      return MakeAndAddRef<GleanEvent>(metricId);
    }
    case 8: /* counter */
    {
      return MakeAndAddRef<GleanCounter>(metricId);
    }
    case 9: /* labeled_counter */
    {
      return MakeAndAddRef<GleanLabeled>(metricId, 9);
    }
    case 10: /* denominator */
    {
      return MakeAndAddRef<GleanDenominator>(metricId);
    }
    case 11: /* numerator */
    {
      return MakeAndAddRef<GleanNumerator>(metricId);
    }
    case 12: /* timing_distribution */
    {
      return MakeAndAddRef<GleanTimingDistribution>(metricId);
    }
    case 13: /* custom_distribution */
    {
      return MakeAndAddRef<GleanCustomDistribution>(metricId);
    }
    case 14: /* labeled_boolean */
    {
      return MakeAndAddRef<GleanLabeled>(metricId, 14);
    }
    case 15: /* timespan */
    {
      return MakeAndAddRef<GleanTimespan>(metricId);
    }
    case 16: /* memory_distribution */
    {
      return MakeAndAddRef<GleanMemoryDistribution>(metricId);
    }
    case 17: /* labeled_string */
    {
      return MakeAndAddRef<GleanLabeled>(metricId, 17);
    }
    case 18: /* url */
    {
      return MakeAndAddRef<GleanUrl>(metricId);
    }
    case 19: /* rate */
    {
      return MakeAndAddRef<GleanRate>(metricId);
    }
    default:
    MOZ_ASSERT_UNREACHABLE("Invalid type ID reached when trying to instantiate a new metric");
    return nullptr;
  }
}

/**
 * Create a submetric instance for a labeled metric of the provided type and id for the given label.
 * Assigns or retrieves an id for the submetric from the SDK.
 *
 * @param aParentTypeId - The type of the parent labeled metric identified as a number generated during codegen.
 *                        Only used to identify which X of LabeledX you are so that X can be created here.
 * @param aParentMetricId - The metric id for the parent labeled metric.
 * @param aLabel - The label for the submetric. Might not adhere to the SDK label format.
 * @param aSubmetricId - an outparam which is assigned the submetric's SDK-generated submetric id.
 *                       Used only by GIFFT.
 */
already_AddRefed<nsISupports> NewSubMetricFromIds(uint32_t aParentTypeId, uint32_t aParentMetricId, const nsACString& aLabel, uint32_t* aSubmetricId) {
  switch (aParentTypeId) {
    case 9: { /* labeled_counter */
      auto id = impl::fog_labeled_counter_get(aParentMetricId, &aLabel);
      *aSubmetricId = id;
      return MakeAndAddRef<GleanCounter>(id);
    }
    case 14: { /* labeled_boolean */
      auto id = impl::fog_labeled_boolean_get(aParentMetricId, &aLabel);
      *aSubmetricId = id;
      return MakeAndAddRef<GleanBoolean>(id);
    }
    case 17: { /* labeled_string */
      auto id = impl::fog_labeled_string_get(aParentMetricId, &aLabel);
      *aSubmetricId = id;
      return MakeAndAddRef<GleanString>(id);
    }
    default: {
      MOZ_ASSERT_UNREACHABLE("Invalid type ID for submetric.");
      return nullptr;
    }
  }
}

static Maybe<uint32_t> category_result_check(const nsACString& aKey, category_entry_t entry);
static Maybe<uint32_t> metric_result_check(const nsACString& aKey, metric_entry_t entry);

#if defined(_MSC_VER) && !defined(__clang__)
const char gCategoryStringTable[] = {
#else
constexpr char gCategoryStringTable[] = {
#endif
  /*     0 - "backgroundUpdate" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'U', 'p', 'd', 'a', 't', 'e', '\0',
  /*    17 - "browserLaunchedToHandle" */ 'b', 'r', 'o', 'w', 's', 'e', 'r', 'L', 'a', 'u', 'n', 'c', 'h', 'e', 'd', 'T', 'o', 'H', 'a', 'n', 'd', 'l', 'e', '\0',
  /*    41 - "newtab" */ 'n', 'e', 'w', 't', 'a', 'b', '\0',
  /*    48 - "newtabSearch" */ 'n', 'e', 'w', 't', 'a', 'b', 'S', 'e', 'a', 'r', 'c', 'h', '\0',
  /*    61 - "pocket" */ 'p', 'o', 'c', 'k', 'e', 't', '\0',
  /*    68 - "topsites" */ 't', 'o', 'p', 's', 'i', 't', 'e', 's', '\0',
  /*    77 - "newtabSearchAd" */ 'n', 'e', 'w', 't', 'a', 'b', 'S', 'e', 'a', 'r', 'c', 'h', 'A', 'd', '\0',
  /*    92 - "serp" */ 's', 'e', 'r', 'p', '\0',
  /*    97 - "urlbar" */ 'u', 'r', 'l', 'b', 'a', 'r', '\0',
  /*   104 - "browserEngagement" */ 'b', 'r', 'o', 'w', 's', 'e', 'r', 'E', 'n', 'g', 'a', 'g', 'e', 'm', 'e', 'n', 't', '\0',
  /*   122 - "pingCentre" */ 'p', 'i', 'n', 'g', 'C', 'e', 'n', 't', 'r', 'e', '\0',
  /*   133 - "gmp" */ 'g', 'm', 'p', '\0',
  /*   137 - "rtcrtpsender" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', '\0',
  /*   150 - "rtcrtpsenderSetparameters" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', 'S', 'e', 't', 'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', '\0',
  /*   176 - "perf" */ 'p', 'e', 'r', 'f', '\0',
  /*   181 - "paint" */ 'p', 'a', 'i', 'n', 't', '\0',
  /*   187 - "wr" */ 'w', 'r', '\0',
  /*   190 - "dotprint" */ 'd', 'o', 't', 'p', 'r', 'i', 'n', 't', '\0',
  /*   199 - "networking" */ 'n', 'e', 't', 'w', 'o', 'r', 'k', 'i', 'n', 'g', '\0',
  /*   210 - "netwerk" */ 'n', 'e', 't', 'w', 'e', 'r', 'k', '\0',
  /*   218 - "network" */ 'n', 'e', 't', 'w', 'o', 'r', 'k', '\0',
  /*   226 - "backgroundTasksRmdirBase" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'B', 'a', 's', 'e', '\0',
  /*   251 - "backgroundTasksRmdirHttpCache" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'H', 't', 't', 'p', 'C', 'a', 'c', 'h', 'e', '\0',
  /*   281 - "backgroundTasksRmdirQuota" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'Q', 'u', 'o', 't', 'a', '\0',
  /*   307 - "cookieBanners" */ 'c', 'o', 'o', 'k', 'i', 'e', 'B', 'a', 'n', 'n', 'e', 'r', 's', '\0',
  /*   321 - "cookieBannersClick" */ 'c', 'o', 'o', 'k', 'i', 'e', 'B', 'a', 'n', 'n', 'e', 'r', 's', 'C', 'l', 'i', 'c', 'k', '\0',
  /*   340 - "crash" */ 'c', 'r', 'a', 's', 'h', '\0',
  /*   346 - "extensions" */ 'e', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 's', '\0',
  /*   357 - "extensionsApisDnr" */ 'e', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 's', 'A', 'p', 'i', 's', 'D', 'n', 'r', '\0',
  /*   375 - "fog" */ 'f', 'o', 'g', '\0',
  /*   379 - "fogIpc" */ 'f', 'o', 'g', 'I', 'p', 'c', '\0',
  /*   386 - "testOnly" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '\0',
  /*   395 - "testOnlyIpc" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '\0',
  /*   407 - "testOnlyJog" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'J', 'o', 'g', '\0',
  /*   419 - "nimbusEvents" */ 'n', 'i', 'm', 'b', 'u', 's', 'E', 'v', 'e', 'n', 't', 's', '\0',
  /*   432 - "pdfjs" */ 'p', 'd', 'f', 'j', 's', '\0',
  /*   438 - "power" */ 'p', 'o', 'w', 'e', 'r', '\0',
  /*   444 - "powerBattery" */ 'p', 'o', 'w', 'e', 'r', 'B', 'a', 't', 't', 'e', 'r', 'y', '\0',
  /*   457 - "powerCpuMsPerThread" */ 'p', 'o', 'w', 'e', 'r', 'C', 'p', 'u', 'M', 's', 'P', 'e', 'r', 'T', 'h', 'r', 'e', 'a', 'd', '\0',
  /*   477 - "powerWakeupsPerThread" */ 'p', 'o', 'w', 'e', 'r', 'W', 'a', 'k', 'e', 'u', 'p', 's', 'P', 'e', 'r', 'T', 'h', 'r', 'e', 'a', 'd', '\0',
  /*   499 - "searchEngineDefault" */ 's', 'e', 'a', 'r', 'c', 'h', 'E', 'n', 'g', 'i', 'n', 'e', 'D', 'e', 'f', 'a', 'u', 'l', 't', '\0',
  /*   519 - "searchEnginePrivate" */ 's', 'e', 'a', 'r', 'c', 'h', 'E', 'n', 'g', 'i', 'n', 'e', 'P', 'r', 'i', 'v', 'a', 't', 'e', '\0',
  /*   539 - "dap" */ 'd', 'a', 'p', '\0',
  /*   543 - "legacyTelemetry" */ 'l', 'e', 'g', 'a', 'c', 'y', 'T', 'e', 'l', 'e', 'm', 'e', 't', 'r', 'y', '\0',
  /*   559 - "firstStartup" */ 'f', 'i', 'r', 's', 't', 'S', 't', 'a', 'r', 't', 'u', 'p', '\0',
  /*   572 - "update" */ 'u', 'p', 'd', 'a', 't', 'e', '\0',
  /*   579 - "startup" */ 's', 't', 'a', 'r', 't', 'u', 'p', '\0',
  /*   587 - "timerThread" */ 't', 'i', 'm', 'e', 'r', 'T', 'h', 'r', 'e', 'a', 'd', '\0',
};


static_assert(sizeof(gCategoryStringTable) < UINT32_MAX, "Category string table is too large.");

const category_entry_t sCategoryByNameLookupEntries[] = {
  572ul,
  386ul,
  395ul,
  438ul,
  97ul,
  150ul,
  357ul,
  133ul,
  379ul,
  579ul,
  587ul,
  375ul,
  340ul,
  499ul,
  61ul,
  251ul,
  187ul,
  407ul,
  307ul,
  477ul,
  190ul,
  218ul,
  122ul,
  68ul,
  444ul,
  543ul,
  77ul,
  210ul,
  457ul,
  48ul,
  432ul,
  539ul,
  0ul,
  281ul,
  176ul,
  137ul,
  226ul,
  92ul,
  419ul,
  346ul,
  181ul,
  559ul,
  104ul,
  41ul,
  321ul,
  199ul,
  519ul,
  17ul
};



Maybe<uint32_t>
CategoryByNameLookup(const nsACString& aKey)
{
  static const uint8_t BASES[] = {
       0,   0,   0,   0,   0,   0,   0,   0,   2,   0,   0,   0,   1,   0,   0,   0,
       3,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   1,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   1,   0,   0,   0,   0,   0,   0,   0,   0,   2,
       0,   0,   0,   0,   1,   0,   1,   1,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   1,   0,   0,
       0,   0,   0,   0,   0,   0,   2,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   1,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   1,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   1,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   5,   0,   0,   0,   0,   0,   1,   0,   0,   0,   2,
       0,   0,   0,   0,   4,   0,   0,   0,   0,   0,   0,   0,   0,   0,   1,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   4,   0,   0,   5,   0,   0,   0,   0,   3,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   1,   1,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       2,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   4,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   2,   0,   0,   0,   1,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   4,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   7,   0,   0,   0,   0,   2,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   1,   0,   0,   0,   0,   0,   0,   1,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   8,   0,   1,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   2,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,  11,   0,
       0,   0,   6,   0,   0,   1,   0,   0,   1,   0,   0,   0,   0,   0,   0,  19,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   6,   0,   0,   0,   0,   0, 139,   0,   0,   0,   0,   0,   0,   0,   0,
  };
  

  const char* bytes = aKey.BeginReading();
  size_t length = aKey.Length();
  auto& entry = mozilla::perfecthash::Lookup(bytes, length, BASES,
                                             sCategoryByNameLookupEntries);
  return category_result_check(aKey, entry);
}


#if defined(_MSC_VER) && !defined(__clang__)
const char gMetricStringTable[] = {
#else
constexpr char gMetricStringTable[] = {
#endif
  /*     0 - "backgroundUpdate.reasonsToNotUpdate" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'U', 'p', 'd', 'a', 't', 'e', '.', 'r', 'e', 'a', 's', 'o', 'n', 's', 'T', 'o', 'N', 'o', 't', 'U', 'p', 'd', 'a', 't', 'e', '\0',
  /*    36 - "backgroundUpdate.timeLastUpdateScheduled" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'U', 'p', 'd', 'a', 't', 'e', '.', 't', 'i', 'm', 'e', 'L', 'a', 's', 't', 'U', 'p', 'd', 'a', 't', 'e', 'S', 'c', 'h', 'e', 'd', 'u', 'l', 'e', 'd', '\0',
  /*    77 - "backgroundUpdate.clientId" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'U', 'p', 'd', 'a', 't', 'e', '.', 'c', 'l', 'i', 'e', 'n', 't', 'I', 'd', '\0',
  /*   103 - "backgroundUpdate.exitCodeException" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'U', 'p', 'd', 'a', 't', 'e', '.', 'e', 'x', 'i', 't', 'C', 'o', 'd', 'e', 'E', 'x', 'c', 'e', 'p', 't', 'i', 'o', 'n', '\0',
  /*   138 - "backgroundUpdate.exitCodeSuccess" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'U', 'p', 'd', 'a', 't', 'e', '.', 'e', 'x', 'i', 't', 'C', 'o', 'd', 'e', 'S', 'u', 'c', 'c', 'e', 's', 's', '\0',
  /*   171 - "backgroundUpdate.finalState" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'U', 'p', 'd', 'a', 't', 'e', '.', 'f', 'i', 'n', 'a', 'l', 'S', 't', 'a', 't', 'e', '\0',
  /*   199 - "backgroundUpdate.reasons" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'U', 'p', 'd', 'a', 't', 'e', '.', 'r', 'e', 'a', 's', 'o', 'n', 's', '\0',
  /*   224 - "backgroundUpdate.states" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'U', 'p', 'd', 'a', 't', 'e', '.', 's', 't', 'a', 't', 'e', 's', '\0',
  /*   248 - "backgroundUpdate.targetingEnvCurrentDate" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'U', 'p', 'd', 'a', 't', 'e', '.', 't', 'a', 'r', 'g', 'e', 't', 'i', 'n', 'g', 'E', 'n', 'v', 'C', 'u', 'r', 'r', 'e', 'n', 't', 'D', 'a', 't', 'e', '\0',
  /*   289 - "backgroundUpdate.targetingEnvFirefoxVersion" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'U', 'p', 'd', 'a', 't', 'e', '.', 't', 'a', 'r', 'g', 'e', 't', 'i', 'n', 'g', 'E', 'n', 'v', 'F', 'i', 'r', 'e', 'f', 'o', 'x', 'V', 'e', 'r', 's', 'i', 'o', 'n', '\0',
  /*   333 - "backgroundUpdate.targetingEnvProfileAge" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'U', 'p', 'd', 'a', 't', 'e', '.', 't', 'a', 'r', 'g', 'e', 't', 'i', 'n', 'g', 'E', 'n', 'v', 'P', 'r', 'o', 'f', 'i', 'l', 'e', 'A', 'g', 'e', '\0',
  /*   373 - "backgroundUpdate.targetingException" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'U', 'p', 'd', 'a', 't', 'e', '.', 't', 'a', 'r', 'g', 'e', 't', 'i', 'n', 'g', 'E', 'x', 'c', 'e', 'p', 't', 'i', 'o', 'n', '\0',
  /*   409 - "backgroundUpdate.targetingExists" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'U', 'p', 'd', 'a', 't', 'e', '.', 't', 'a', 'r', 'g', 'e', 't', 'i', 'n', 'g', 'E', 'x', 'i', 's', 't', 's', '\0',
  /*   442 - "backgroundUpdate.targetingVersion" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'U', 'p', 'd', 'a', 't', 'e', '.', 't', 'a', 'r', 'g', 'e', 't', 'i', 'n', 'g', 'V', 'e', 'r', 's', 'i', 'o', 'n', '\0',
  /*   476 - "browserLaunchedToHandle.systemNotification" */ 'b', 'r', 'o', 'w', 's', 'e', 'r', 'L', 'a', 'u', 'n', 'c', 'h', 'e', 'd', 'T', 'o', 'H', 'a', 'n', 'd', 'l', 'e', '.', 's', 'y', 's', 't', 'e', 'm', 'N', 'o', 't', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\0',
  /*   519 - "newtab.blockedSponsors" */ 'n', 'e', 'w', 't', 'a', 'b', '.', 'b', 'l', 'o', 'c', 'k', 'e', 'd', 'S', 'p', 'o', 'n', 's', 'o', 'r', 's', '\0',
  /*   542 - "newtab.closed" */ 'n', 'e', 'w', 't', 'a', 'b', '.', 'c', 'l', 'o', 's', 'e', 'd', '\0',
  /*   556 - "newtab.homepageCategory" */ 'n', 'e', 'w', 't', 'a', 'b', '.', 'h', 'o', 'm', 'e', 'p', 'a', 'g', 'e', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'y', '\0',
  /*   580 - "newtab.locale" */ 'n', 'e', 'w', 't', 'a', 'b', '.', 'l', 'o', 'c', 'a', 'l', 'e', '\0',
  /*   594 - "newtab.newtabCategory" */ 'n', 'e', 'w', 't', 'a', 'b', '.', 'n', 'e', 'w', 't', 'a', 'b', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'y', '\0',
  /*   616 - "newtab.opened" */ 'n', 'e', 'w', 't', 'a', 'b', '.', 'o', 'p', 'e', 'n', 'e', 'd', '\0',
  /*   630 - "newtabSearch.enabled" */ 'n', 'e', 'w', 't', 'a', 'b', 'S', 'e', 'a', 'r', 'c', 'h', '.', 'e', 'n', 'a', 'b', 'l', 'e', 'd', '\0',
  /*   651 - "newtabSearch.issued" */ 'n', 'e', 'w', 't', 'a', 'b', 'S', 'e', 'a', 'r', 'c', 'h', '.', 'i', 's', 's', 'u', 'e', 'd', '\0',
  /*   671 - "pocket.click" */ 'p', 'o', 'c', 'k', 'e', 't', '.', 'c', 'l', 'i', 'c', 'k', '\0',
  /*   684 - "pocket.enabled" */ 'p', 'o', 'c', 'k', 'e', 't', '.', 'e', 'n', 'a', 'b', 'l', 'e', 'd', '\0',
  /*   699 - "pocket.impression" */ 'p', 'o', 'c', 'k', 'e', 't', '.', 'i', 'm', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', '\0',
  /*   717 - "pocket.isSignedIn" */ 'p', 'o', 'c', 'k', 'e', 't', '.', 'i', 's', 'S', 'i', 'g', 'n', 'e', 'd', 'I', 'n', '\0',
  /*   735 - "pocket.save" */ 'p', 'o', 'c', 'k', 'e', 't', '.', 's', 'a', 'v', 'e', '\0',
  /*   747 - "pocket.sponsoredStoriesEnabled" */ 'p', 'o', 'c', 'k', 'e', 't', '.', 's', 'p', 'o', 'n', 's', 'o', 'r', 'e', 'd', 'S', 't', 'o', 'r', 'i', 'e', 's', 'E', 'n', 'a', 'b', 'l', 'e', 'd', '\0',
  /*   778 - "pocket.topicClick" */ 'p', 'o', 'c', 'k', 'e', 't', '.', 't', 'o', 'p', 'i', 'c', 'C', 'l', 'i', 'c', 'k', '\0',
  /*   796 - "topsites.click" */ 't', 'o', 'p', 's', 'i', 't', 'e', 's', '.', 'c', 'l', 'i', 'c', 'k', '\0',
  /*   811 - "topsites.enabled" */ 't', 'o', 'p', 's', 'i', 't', 'e', 's', '.', 'e', 'n', 'a', 'b', 'l', 'e', 'd', '\0',
  /*   828 - "topsites.impression" */ 't', 'o', 'p', 's', 'i', 't', 'e', 's', '.', 'i', 'm', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', '\0',
  /*   848 - "topsites.rows" */ 't', 'o', 'p', 's', 'i', 't', 'e', 's', '.', 'r', 'o', 'w', 's', '\0',
  /*   862 - "topsites.sponsoredEnabled" */ 't', 'o', 'p', 's', 'i', 't', 'e', 's', '.', 's', 'p', 'o', 'n', 's', 'o', 'r', 'e', 'd', 'E', 'n', 'a', 'b', 'l', 'e', 'd', '\0',
  /*   888 - "newtabSearchAd.click" */ 'n', 'e', 'w', 't', 'a', 'b', 'S', 'e', 'a', 'r', 'c', 'h', 'A', 'd', '.', 'c', 'l', 'i', 'c', 'k', '\0',
  /*   909 - "newtabSearchAd.impression" */ 'n', 'e', 'w', 't', 'a', 'b', 'S', 'e', 'a', 'r', 'c', 'h', 'A', 'd', '.', 'i', 'm', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', '\0',
  /*   935 - "serp.abandonment" */ 's', 'e', 'r', 'p', '.', 'a', 'b', 'a', 'n', 'd', 'o', 'n', 'm', 'e', 'n', 't', '\0',
  /*   952 - "serp.adImpression" */ 's', 'e', 'r', 'p', '.', 'a', 'd', 'I', 'm', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', '\0',
  /*   970 - "serp.engagement" */ 's', 'e', 'r', 'p', '.', 'e', 'n', 'g', 'a', 'g', 'e', 'm', 'e', 'n', 't', '\0',
  /*   986 - "serp.impression" */ 's', 'e', 'r', 'p', '.', 'i', 'm', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', '\0',
  /*  1002 - "urlbar.abandonment" */ 'u', 'r', 'l', 'b', 'a', 'r', '.', 'a', 'b', 'a', 'n', 'd', 'o', 'n', 'm', 'e', 'n', 't', '\0',
  /*  1021 - "urlbar.engagement" */ 'u', 'r', 'l', 'b', 'a', 'r', '.', 'e', 'n', 'g', 'a', 'g', 'e', 'm', 'e', 'n', 't', '\0',
  /*  1039 - "urlbar.exposure" */ 'u', 'r', 'l', 'b', 'a', 'r', '.', 'e', 'x', 'p', 'o', 's', 'u', 'r', 'e', '\0',
  /*  1055 - "urlbar.impression" */ 'u', 'r', 'l', 'b', 'a', 'r', '.', 'i', 'm', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', '\0',
  /*  1073 - "urlbar.prefMaxResults" */ 'u', 'r', 'l', 'b', 'a', 'r', '.', 'p', 'r', 'e', 'f', 'M', 'a', 'x', 'R', 'e', 's', 'u', 'l', 't', 's', '\0',
  /*  1095 - "urlbar.prefSuggestTopsites" */ 'u', 'r', 'l', 'b', 'a', 'r', '.', 'p', 'r', 'e', 'f', 'S', 'u', 'g', 'g', 'e', 's', 't', 'T', 'o', 'p', 's', 'i', 't', 'e', 's', '\0',
  /*  1122 - "browserEngagement.activeTicks" */ 'b', 'r', 'o', 'w', 's', 'e', 'r', 'E', 'n', 'g', 'a', 'g', 'e', 'm', 'e', 'n', 't', '.', 'a', 'c', 't', 'i', 'v', 'e', 'T', 'i', 'c', 'k', 's', '\0',
  /*  1152 - "browserEngagement.profileCount" */ 'b', 'r', 'o', 'w', 's', 'e', 'r', 'E', 'n', 'g', 'a', 'g', 'e', 'm', 'e', 'n', 't', '.', 'p', 'r', 'o', 'f', 'i', 'l', 'e', 'C', 'o', 'u', 'n', 't', '\0',
  /*  1183 - "browserEngagement.uriCount" */ 'b', 'r', 'o', 'w', 's', 'e', 'r', 'E', 'n', 'g', 'a', 'g', 'e', 'm', 'e', 'n', 't', '.', 'u', 'r', 'i', 'C', 'o', 'u', 'n', 't', '\0',
  /*  1210 - "pingCentre.sendFailures" */ 'p', 'i', 'n', 'g', 'C', 'e', 'n', 't', 'r', 'e', '.', 's', 'e', 'n', 'd', 'F', 'a', 'i', 'l', 'u', 'r', 'e', 's', '\0',
  /*  1234 - "pingCentre.sendFailuresByNamespace" */ 'p', 'i', 'n', 'g', 'C', 'e', 'n', 't', 'r', 'e', '.', 's', 'e', 'n', 'd', 'F', 'a', 'i', 'l', 'u', 'r', 'e', 's', 'B', 'y', 'N', 'a', 'm', 'e', 's', 'p', 'a', 'c', 'e', '\0',
  /*  1269 - "pingCentre.sendSuccessesByNamespace" */ 'p', 'i', 'n', 'g', 'C', 'e', 'n', 't', 'r', 'e', '.', 's', 'e', 'n', 'd', 'S', 'u', 'c', 'c', 'e', 's', 's', 'e', 's', 'B', 'y', 'N', 'a', 'm', 'e', 's', 'p', 'a', 'c', 'e', '\0',
  /*  1305 - "gmp.updateXmlFetchResult" */ 'g', 'm', 'p', '.', 'u', 'p', 'd', 'a', 't', 'e', 'X', 'm', 'l', 'F', 'e', 't', 'c', 'h', 'R', 'e', 's', 'u', 'l', 't', '\0',
  /*  1330 - "rtcrtpsender.count" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', '.', 'c', 'o', 'u', 'n', 't', '\0',
  /*  1349 - "rtcrtpsender.countSetparametersCompat" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', '.', 'c', 'o', 'u', 'n', 't', 'S', 'e', 't', 'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', 'C', 'o', 'm', 'p', 'a', 't', '\0',
  /*  1387 - "rtcrtpsender.usedSendencodings" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', '.', 'u', 's', 'e', 'd', 'S', 'e', 'n', 'd', 'e', 'n', 'c', 'o', 'd', 'i', 'n', 'g', 's', '\0',
  /*  1418 - "rtcrtpsenderSetparameters.failLengthChanged" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', 'S', 'e', 't', 'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', '.', 'f', 'a', 'i', 'l', 'L', 'e', 'n', 'g', 't', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', '\0',
  /*  1462 - "rtcrtpsenderSetparameters.failNoEncodings" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', 'S', 'e', 't', 'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', '.', 'f', 'a', 'i', 'l', 'N', 'o', 'E', 'n', 'c', 'o', 'd', 'i', 'n', 'g', 's', '\0',
  /*  1504 - "rtcrtpsenderSetparameters.failNoGetparameters" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', 'S', 'e', 't', 'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', '.', 'f', 'a', 'i', 'l', 'N', 'o', 'G', 'e', 't', 'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', '\0',
  /*  1550 - "rtcrtpsenderSetparameters.failNoTransactionid" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', 'S', 'e', 't', 'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', '.', 'f', 'a', 'i', 'l', 'N', 'o', 'T', 'r', 'a', 'n', 's', 'a', 'c', 't', 'i', 'o', 'n', 'i', 'd', '\0',
  /*  1596 - "rtcrtpsenderSetparameters.failOther" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', 'S', 'e', 't', 'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', '.', 'f', 'a', 'i', 'l', 'O', 't', 'h', 'e', 'r', '\0',
  /*  1632 - "rtcrtpsenderSetparameters.failRidChanged" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', 'S', 'e', 't', 'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', '.', 'f', 'a', 'i', 'l', 'R', 'i', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', '\0',
  /*  1673 - "rtcrtpsenderSetparameters.failStaleTransactionid" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', 'S', 'e', 't', 'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', '.', 'f', 'a', 'i', 'l', 'S', 't', 'a', 'l', 'e', 'T', 'r', 'a', 'n', 's', 'a', 'c', 't', 'i', 'o', 'n', 'i', 'd', '\0',
  /*  1722 - "rtcrtpsenderSetparameters.warnLengthChanged" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', 'S', 'e', 't', 'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', '.', 'w', 'a', 'r', 'n', 'L', 'e', 'n', 'g', 't', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', '\0',
  /*  1766 - "rtcrtpsenderSetparameters.warnNoGetparameters" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', 'S', 'e', 't', 'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', '.', 'w', 'a', 'r', 'n', 'N', 'o', 'G', 'e', 't', 'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', '\0',
  /*  1812 - "rtcrtpsenderSetparameters.warnNoTransactionid" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', 'S', 'e', 't', 'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', '.', 'w', 'a', 'r', 'n', 'N', 'o', 'T', 'r', 'a', 'n', 's', 'a', 'c', 't', 'i', 'o', 'n', 'i', 'd', '\0',
  /*  1858 - "rtcrtpsenderSetparameters.warnRidChanged" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', 'S', 'e', 't', 'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', '.', 'w', 'a', 'r', 'n', 'R', 'i', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', '\0',
  /*  1899 - "rtcrtpsenderSetparameters.warnStaleTransactionid" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', 'S', 'e', 't', 'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', '.', 'w', 'a', 'r', 'n', 'S', 't', 'a', 'l', 'e', 'T', 'r', 'a', 'n', 's', 'a', 'c', 't', 'i', 'o', 'n', 'i', 'd', '\0',
  /*  1948 - "perf.pageLoad" */ 'p', 'e', 'r', 'f', '.', 'p', 'a', 'g', 'e', 'L', 'o', 'a', 'd', '\0',
  /*  1962 - "paint.buildDisplaylistTime" */ 'p', 'a', 'i', 'n', 't', '.', 'b', 'u', 'i', 'l', 'd', 'D', 'i', 's', 'p', 'l', 'a', 'y', 'l', 'i', 's', 't', 'T', 'i', 'm', 'e', '\0',
  /*  1989 - "wr.framebuildTime" */ 'w', 'r', '.', 'f', 'r', 'a', 'm', 'e', 'b', 'u', 'i', 'l', 'd', 'T', 'i', 'm', 'e', '\0',
  /*  2007 - "wr.gpuWaitTime" */ 'w', 'r', '.', 'g', 'p', 'u', 'W', 'a', 'i', 't', 'T', 'i', 'm', 'e', '\0',
  /*  2022 - "wr.rasterizeBlobsTime" */ 'w', 'r', '.', 'r', 'a', 's', 't', 'e', 'r', 'i', 'z', 'e', 'B', 'l', 'o', 'b', 's', 'T', 'i', 'm', 'e', '\0',
  /*  2044 - "wr.rasterizeGlyphsTime" */ 'w', 'r', '.', 'r', 'a', 's', 't', 'e', 'r', 'i', 'z', 'e', 'G', 'l', 'y', 'p', 'h', 's', 'T', 'i', 'm', 'e', '\0',
  /*  2067 - "wr.rendererTime" */ 'w', 'r', '.', 'r', 'e', 'n', 'd', 'e', 'r', 'e', 'r', 'T', 'i', 'm', 'e', '\0',
  /*  2083 - "wr.rendererTimeNoSc" */ 'w', 'r', '.', 'r', 'e', 'n', 'd', 'e', 'r', 'e', 'r', 'T', 'i', 'm', 'e', 'N', 'o', 'S', 'c', '\0',
  /*  2103 - "wr.scenebuildTime" */ 'w', 'r', '.', 's', 'c', 'e', 'n', 'e', 'b', 'u', 'i', 'l', 'd', 'T', 'i', 'm', 'e', '\0',
  /*  2121 - "wr.sceneswapTime" */ 'w', 'r', '.', 's', 'c', 'e', 'n', 'e', 's', 'w', 'a', 'p', 'T', 'i', 'm', 'e', '\0',
  /*  2138 - "wr.textureCacheUpdateTime" */ 'w', 'r', '.', 't', 'e', 'x', 't', 'u', 'r', 'e', 'C', 'a', 'c', 'h', 'e', 'U', 'p', 'd', 'a', 't', 'e', 'T', 'i', 'm', 'e', '\0',
  /*  2164 - "wr.timeToFrameBuild" */ 'w', 'r', '.', 't', 'i', 'm', 'e', 'T', 'o', 'F', 'r', 'a', 'm', 'e', 'B', 'u', 'i', 'l', 'd', '\0',
  /*  2184 - "wr.timeToRenderStart" */ 'w', 'r', '.', 't', 'i', 'm', 'e', 'T', 'o', 'R', 'e', 'n', 'd', 'e', 'r', 'S', 't', 'a', 'r', 't', '\0',
  /*  2205 - "dotprint.requested" */ 'd', 'o', 't', 'p', 'r', 'i', 'n', 't', '.', 'r', 'e', 'q', 'u', 'e', 's', 't', 'e', 'd', '\0',
  /*  2224 - "networking.cookieAccessFixupDiff" */ 'n', 'e', 't', 'w', 'o', 'r', 'k', 'i', 'n', 'g', '.', 'c', 'o', 'o', 'k', 'i', 'e', 'A', 'c', 'c', 'e', 's', 's', 'F', 'i', 'x', 'u', 'p', 'D', 'i', 'f', 'f', '\0',
  /*  2257 - "networking.cookieCreationFixupDiff" */ 'n', 'e', 't', 'w', 'o', 'r', 'k', 'i', 'n', 'g', '.', 'c', 'o', 'o', 'k', 'i', 'e', 'C', 'r', 'e', 'a', 't', 'i', 'o', 'n', 'F', 'i', 'x', 'u', 'p', 'D', 'i', 'f', 'f', '\0',
  /*  2292 - "networking.cookieTimestampFixedCount" */ 'n', 'e', 't', 'w', 'o', 'r', 'k', 'i', 'n', 'g', '.', 'c', 'o', 'o', 'k', 'i', 'e', 'T', 'i', 'm', 'e', 's', 't', 'a', 'm', 'p', 'F', 'i', 'x', 'e', 'd', 'C', 'o', 'u', 'n', 't', '\0',
  /*  2329 - "networking.speculativeConnectOutcome" */ 'n', 'e', 't', 'w', 'o', 'r', 'k', 'i', 'n', 'g', '.', 's', 'p', 'e', 'c', 'u', 'l', 'a', 't', 'i', 'v', 'e', 'C', 'o', 'n', 'n', 'e', 'c', 't', 'O', 'u', 't', 'c', 'o', 'm', 'e', '\0',
  /*  2366 - "netwerk.earlyHints" */ 'n', 'e', 't', 'w', 'e', 'r', 'k', '.', 'e', 'a', 'r', 'l', 'y', 'H', 'i', 'n', 't', 's', '\0',
  /*  2385 - "netwerk.ehLinkType" */ 'n', 'e', 't', 'w', 'e', 'r', 'k', '.', 'e', 'h', 'L', 'i', 'n', 'k', 'T', 'y', 'p', 'e', '\0',
  /*  2404 - "network.dataSizePbPerType" */ 'n', 'e', 't', 'w', 'o', 'r', 'k', '.', 'd', 'a', 't', 'a', 'S', 'i', 'z', 'e', 'P', 'b', 'P', 'e', 'r', 'T', 'y', 'p', 'e', '\0',
  /*  2430 - "network.dataSizePerType" */ 'n', 'e', 't', 'w', 'o', 'r', 'k', '.', 'd', 'a', 't', 'a', 'S', 'i', 'z', 'e', 'P', 'e', 'r', 'T', 'y', 'p', 'e', '\0',
  /*  2454 - "backgroundTasksRmdirBase.elapsedMs" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'B', 'a', 's', 'e', '.', 'e', 'l', 'a', 'p', 's', 'e', 'd', 'M', 's', '\0',
  /*  2489 - "backgroundTasksRmdirBase.metricBase" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'B', 'a', 's', 'e', '.', 'm', 'e', 't', 'r', 'i', 'c', 'B', 'a', 's', 'e', '\0',
  /*  2525 - "backgroundTasksRmdirBase.removalCount" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'B', 'a', 's', 'e', '.', 'r', 'e', 'm', 'o', 'v', 'a', 'l', 'C', 'o', 'u', 'n', 't', '\0',
  /*  2563 - "backgroundTasksRmdirBase.retryCount" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'B', 'a', 's', 'e', '.', 'r', 'e', 't', 'r', 'y', 'C', 'o', 'u', 'n', 't', '\0',
  /*  2599 - "backgroundTasksRmdirBase.succeeded" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'B', 'a', 's', 'e', '.', 's', 'u', 'c', 'c', 'e', 'e', 'd', 'e', 'd', '\0',
  /*  2634 - "backgroundTasksRmdirBase.suffixEverFailed" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'B', 'a', 's', 'e', '.', 's', 'u', 'f', 'f', 'i', 'x', 'E', 'v', 'e', 'r', 'F', 'a', 'i', 'l', 'e', 'd', '\0',
  /*  2676 - "backgroundTasksRmdirBase.suffixRemovalCount" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'B', 'a', 's', 'e', '.', 's', 'u', 'f', 'f', 'i', 'x', 'R', 'e', 'm', 'o', 'v', 'a', 'l', 'C', 'o', 'u', 'n', 't', '\0',
  /*  2720 - "backgroundTasksRmdirBase.wasFirst" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'B', 'a', 's', 'e', '.', 'w', 'a', 's', 'F', 'i', 'r', 's', 't', '\0',
  /*  2754 - "backgroundTasksRmdirHttpCache.elapsedMs" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'H', 't', 't', 'p', 'C', 'a', 'c', 'h', 'e', '.', 'e', 'l', 'a', 'p', 's', 'e', 'd', 'M', 's', '\0',
  /*  2794 - "backgroundTasksRmdirHttpCache.metricBase" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'H', 't', 't', 'p', 'C', 'a', 'c', 'h', 'e', '.', 'm', 'e', 't', 'r', 'i', 'c', 'B', 'a', 's', 'e', '\0',
  /*  2835 - "backgroundTasksRmdirHttpCache.removalCount" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'H', 't', 't', 'p', 'C', 'a', 'c', 'h', 'e', '.', 'r', 'e', 'm', 'o', 'v', 'a', 'l', 'C', 'o', 'u', 'n', 't', '\0',
  /*  2878 - "backgroundTasksRmdirHttpCache.retryCount" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'H', 't', 't', 'p', 'C', 'a', 'c', 'h', 'e', '.', 'r', 'e', 't', 'r', 'y', 'C', 'o', 'u', 'n', 't', '\0',
  /*  2919 - "backgroundTasksRmdirHttpCache.succeeded" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'H', 't', 't', 'p', 'C', 'a', 'c', 'h', 'e', '.', 's', 'u', 'c', 'c', 'e', 'e', 'd', 'e', 'd', '\0',
  /*  2959 - "backgroundTasksRmdirHttpCache.suffixEverFailed" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'H', 't', 't', 'p', 'C', 'a', 'c', 'h', 'e', '.', 's', 'u', 'f', 'f', 'i', 'x', 'E', 'v', 'e', 'r', 'F', 'a', 'i', 'l', 'e', 'd', '\0',
  /*  3006 - "backgroundTasksRmdirHttpCache.suffixRemovalCount" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'H', 't', 't', 'p', 'C', 'a', 'c', 'h', 'e', '.', 's', 'u', 'f', 'f', 'i', 'x', 'R', 'e', 'm', 'o', 'v', 'a', 'l', 'C', 'o', 'u', 'n', 't', '\0',
  /*  3055 - "backgroundTasksRmdirHttpCache.wasFirst" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'H', 't', 't', 'p', 'C', 'a', 'c', 'h', 'e', '.', 'w', 'a', 's', 'F', 'i', 'r', 's', 't', '\0',
  /*  3094 - "backgroundTasksRmdirQuota.elapsedMs" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'Q', 'u', 'o', 't', 'a', '.', 'e', 'l', 'a', 'p', 's', 'e', 'd', 'M', 's', '\0',
  /*  3130 - "backgroundTasksRmdirQuota.metricBase" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'Q', 'u', 'o', 't', 'a', '.', 'm', 'e', 't', 'r', 'i', 'c', 'B', 'a', 's', 'e', '\0',
  /*  3167 - "backgroundTasksRmdirQuota.removalCount" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'Q', 'u', 'o', 't', 'a', '.', 'r', 'e', 'm', 'o', 'v', 'a', 'l', 'C', 'o', 'u', 'n', 't', '\0',
  /*  3206 - "backgroundTasksRmdirQuota.retryCount" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'Q', 'u', 'o', 't', 'a', '.', 'r', 'e', 't', 'r', 'y', 'C', 'o', 'u', 'n', 't', '\0',
  /*  3243 - "backgroundTasksRmdirQuota.succeeded" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'Q', 'u', 'o', 't', 'a', '.', 's', 'u', 'c', 'c', 'e', 'e', 'd', 'e', 'd', '\0',
  /*  3279 - "backgroundTasksRmdirQuota.suffixEverFailed" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'Q', 'u', 'o', 't', 'a', '.', 's', 'u', 'f', 'f', 'i', 'x', 'E', 'v', 'e', 'r', 'F', 'a', 'i', 'l', 'e', 'd', '\0',
  /*  3322 - "backgroundTasksRmdirQuota.suffixRemovalCount" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'Q', 'u', 'o', 't', 'a', '.', 's', 'u', 'f', 'f', 'i', 'x', 'R', 'e', 'm', 'o', 'v', 'a', 'l', 'C', 'o', 'u', 'n', 't', '\0',
  /*  3367 - "backgroundTasksRmdirQuota.wasFirst" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'Q', 'u', 'o', 't', 'a', '.', 'w', 'a', 's', 'F', 'i', 'r', 's', 't', '\0',
  /*  3402 - "cookieBanners.normalWindowServiceMode" */ 'c', 'o', 'o', 'k', 'i', 'e', 'B', 'a', 'n', 'n', 'e', 'r', 's', '.', 'n', 'o', 'r', 'm', 'a', 'l', 'W', 'i', 'n', 'd', 'o', 'w', 'S', 'e', 'r', 'v', 'i', 'c', 'e', 'M', 'o', 'd', 'e', '\0',
  /*  3440 - "cookieBanners.privateWindowServiceMode" */ 'c', 'o', 'o', 'k', 'i', 'e', 'B', 'a', 'n', 'n', 'e', 'r', 's', '.', 'p', 'r', 'i', 'v', 'a', 't', 'e', 'W', 'i', 'n', 'd', 'o', 'w', 'S', 'e', 'r', 'v', 'i', 'c', 'e', 'M', 'o', 'd', 'e', '\0',
  /*  3479 - "cookieBanners.reload" */ 'c', 'o', 'o', 'k', 'i', 'e', 'B', 'a', 'n', 'n', 'e', 'r', 's', '.', 'r', 'e', 'l', 'o', 'a', 'd', '\0',
  /*  3500 - "cookieBanners.ruleLookupByDomain" */ 'c', 'o', 'o', 'k', 'i', 'e', 'B', 'a', 'n', 'n', 'e', 'r', 's', '.', 'r', 'u', 'l', 'e', 'L', 'o', 'o', 'k', 'u', 'p', 'B', 'y', 'D', 'o', 'm', 'a', 'i', 'n', '\0',
  /*  3533 - "cookieBanners.ruleLookupByLoad" */ 'c', 'o', 'o', 'k', 'i', 'e', 'B', 'a', 'n', 'n', 'e', 'r', 's', '.', 'r', 'u', 'l', 'e', 'L', 'o', 'o', 'k', 'u', 'p', 'B', 'y', 'L', 'o', 'a', 'd', '\0',
  /*  3564 - "cookieBanners.serviceDetectOnly" */ 'c', 'o', 'o', 'k', 'i', 'e', 'B', 'a', 'n', 'n', 'e', 'r', 's', '.', 's', 'e', 'r', 'v', 'i', 'c', 'e', 'D', 'e', 't', 'e', 'c', 't', 'O', 'n', 'l', 'y', '\0',
  /*  3596 - "cookieBannersClick.handleDuration" */ 'c', 'o', 'o', 'k', 'i', 'e', 'B', 'a', 'n', 'n', 'e', 'r', 's', 'C', 'l', 'i', 'c', 'k', '.', 'h', 'a', 'n', 'd', 'l', 'e', 'D', 'u', 'r', 'a', 't', 'i', 'o', 'n', '\0',
  /*  3630 - "cookieBannersClick.result" */ 'c', 'o', 'o', 'k', 'i', 'e', 'B', 'a', 'n', 'n', 'e', 'r', 's', 'C', 'l', 'i', 'c', 'k', '.', 'r', 'e', 's', 'u', 'l', 't', '\0',
  /*  3656 - "crash.processType" */ 'c', 'r', 'a', 's', 'h', '.', 'p', 'r', 'o', 'c', 'e', 's', 's', 'T', 'y', 'p', 'e', '\0',
  /*  3674 - "crash.startup" */ 'c', 'r', 'a', 's', 'h', '.', 's', 't', 'a', 'r', 't', 'u', 'p', '\0',
  /*  3688 - "crash.time" */ 'c', 'r', 'a', 's', 'h', '.', 't', 'i', 'm', 'e', '\0',
  /*  3699 - "crash.uptime" */ 'c', 'r', 'a', 's', 'h', '.', 'u', 'p', 't', 'i', 'm', 'e', '\0',
  /*  3712 - "extensions.startupCacheLoadTime" */ 'e', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 's', '.', 's', 't', 'a', 'r', 't', 'u', 'p', 'C', 'a', 'c', 'h', 'e', 'L', 'o', 'a', 'd', 'T', 'i', 'm', 'e', '\0',
  /*  3744 - "extensionsApisDnr.evaluateRulesCountMax" */ 'e', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 's', 'A', 'p', 'i', 's', 'D', 'n', 'r', '.', 'e', 'v', 'a', 'l', 'u', 'a', 't', 'e', 'R', 'u', 'l', 'e', 's', 'C', 'o', 'u', 'n', 't', 'M', 'a', 'x', '\0',
  /*  3784 - "extensionsApisDnr.evaluateRulesTime" */ 'e', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 's', 'A', 'p', 'i', 's', 'D', 'n', 'r', '.', 'e', 'v', 'a', 'l', 'u', 'a', 't', 'e', 'R', 'u', 'l', 'e', 's', 'T', 'i', 'm', 'e', '\0',
  /*  3820 - "extensionsApisDnr.startupCacheEntries" */ 'e', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 's', 'A', 'p', 'i', 's', 'D', 'n', 'r', '.', 's', 't', 'a', 'r', 't', 'u', 'p', 'C', 'a', 'c', 'h', 'e', 'E', 'n', 't', 'r', 'i', 'e', 's', '\0',
  /*  3858 - "extensionsApisDnr.startupCacheReadSize" */ 'e', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 's', 'A', 'p', 'i', 's', 'D', 'n', 'r', '.', 's', 't', 'a', 'r', 't', 'u', 'p', 'C', 'a', 'c', 'h', 'e', 'R', 'e', 'a', 'd', 'S', 'i', 'z', 'e', '\0',
  /*  3897 - "extensionsApisDnr.startupCacheReadTime" */ 'e', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 's', 'A', 'p', 'i', 's', 'D', 'n', 'r', '.', 's', 't', 'a', 'r', 't', 'u', 'p', 'C', 'a', 'c', 'h', 'e', 'R', 'e', 'a', 'd', 'T', 'i', 'm', 'e', '\0',
  /*  3936 - "extensionsApisDnr.startupCacheWriteSize" */ 'e', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 's', 'A', 'p', 'i', 's', 'D', 'n', 'r', '.', 's', 't', 'a', 'r', 't', 'u', 'p', 'C', 'a', 'c', 'h', 'e', 'W', 'r', 'i', 't', 'e', 'S', 'i', 'z', 'e', '\0',
  /*  3976 - "extensionsApisDnr.startupCacheWriteTime" */ 'e', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 's', 'A', 'p', 'i', 's', 'D', 'n', 'r', '.', 's', 't', 'a', 'r', 't', 'u', 'p', 'C', 'a', 'c', 'h', 'e', 'W', 'r', 'i', 't', 'e', 'T', 'i', 'm', 'e', '\0',
  /*  4016 - "extensionsApisDnr.validateRulesTime" */ 'e', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 's', 'A', 'p', 'i', 's', 'D', 'n', 'r', '.', 'v', 'a', 'l', 'i', 'd', 'a', 't', 'e', 'R', 'u', 'l', 'e', 's', 'T', 'i', 'm', 'e', '\0',
  /*  4052 - "fog.failedIdleRegistration" */ 'f', 'o', 'g', '.', 'f', 'a', 'i', 'l', 'e', 'd', 'I', 'd', 'l', 'e', 'R', 'e', 'g', 'i', 's', 't', 'r', 'a', 't', 'i', 'o', 'n', '\0',
  /*  4079 - "fog.initialization" */ 'f', 'o', 'g', '.', 'i', 'n', 'i', 't', 'i', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', '\0',
  /*  4098 - "fogIpc.bufferSizes" */ 'f', 'o', 'g', 'I', 'p', 'c', '.', 'b', 'u', 'f', 'f', 'e', 'r', 'S', 'i', 'z', 'e', 's', '\0',
  /*  4117 - "fogIpc.flushDurations" */ 'f', 'o', 'g', 'I', 'p', 'c', '.', 'f', 'l', 'u', 's', 'h', 'D', 'u', 'r', 'a', 't', 'i', 'o', 'n', 's', '\0',
  /*  4139 - "fogIpc.flushFailures" */ 'f', 'o', 'g', 'I', 'p', 'c', '.', 'f', 'l', 'u', 's', 'h', 'F', 'a', 'i', 'l', 'u', 'r', 'e', 's', '\0',
  /*  4160 - "fogIpc.replayFailures" */ 'f', 'o', 'g', 'I', 'p', 'c', '.', 'r', 'e', 'p', 'l', 'a', 'y', 'F', 'a', 'i', 'l', 'u', 'r', 'e', 's', '\0',
  /*  4182 - "fogIpc.shutdownRegistrationFailures" */ 'f', 'o', 'g', 'I', 'p', 'c', '.', 's', 'h', 'u', 't', 'd', 'o', 'w', 'n', 'R', 'e', 'g', 'i', 's', 't', 'r', 'a', 't', 'i', 'o', 'n', 'F', 'a', 'i', 'l', 'u', 'r', 'e', 's', '\0',
  /*  4218 - "testOnly.badCode" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'b', 'a', 'd', 'C', 'o', 'd', 'e', '\0',
  /*  4235 - "testOnly.canWeFlagIt" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'c', 'a', 'n', 'W', 'e', 'F', 'l', 'a', 'g', 'I', 't', '\0',
  /*  4256 - "testOnly.canWeTimeIt" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'c', 'a', 'n', 'W', 'e', 'T', 'i', 'm', 'e', 'I', 't', '\0',
  /*  4277 - "testOnly.cheesyString" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'c', 'h', 'e', 'e', 's', 'y', 'S', 't', 'r', 'i', 'n', 'g', '\0',
  /*  4299 - "testOnly.cheesyStringList" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'c', 'h', 'e', 'e', 's', 'y', 'S', 't', 'r', 'i', 'n', 'g', 'L', 'i', 's', 't', '\0',
  /*  4325 - "testOnly.doYouRemember" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'd', 'o', 'Y', 'o', 'u', 'R', 'e', 'm', 'e', 'm', 'b', 'e', 'r', '\0',
  /*  4348 - "testOnly.mabelsBalloonLabels" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'm', 'a', 'b', 'e', 'l', 's', 'B', 'a', 'l', 'l', 'o', 'o', 'n', 'L', 'a', 'b', 'e', 'l', 's', '\0',
  /*  4377 - "testOnly.mabelsBalloonStrings" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'm', 'a', 'b', 'e', 'l', 's', 'B', 'a', 'l', 'l', 'o', 'o', 'n', 'S', 't', 'r', 'i', 'n', 'g', 's', '\0',
  /*  4407 - "testOnly.mabelsBathroomCounters" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'm', 'a', 'b', 'e', 'l', 's', 'B', 'a', 't', 'h', 'r', 'o', 'o', 'm', 'C', 'o', 'u', 'n', 't', 'e', 'r', 's', '\0',
  /*  4439 - "testOnly.mabelsKitchenCounters" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'm', 'a', 'b', 'e', 'l', 's', 'K', 'i', 't', 'c', 'h', 'e', 'n', 'C', 'o', 'u', 'n', 't', 'e', 'r', 's', '\0',
  /*  4470 - "testOnly.mabelsLabelMaker" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'm', 'a', 'b', 'e', 'l', 's', 'L', 'a', 'b', 'e', 'l', 'M', 'a', 'k', 'e', 'r', '\0',
  /*  4496 - "testOnly.mabelsLabeledCounters" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'm', 'a', 'b', 'e', 'l', 's', 'L', 'a', 'b', 'e', 'l', 'e', 'd', 'C', 'o', 'u', 'n', 't', 'e', 'r', 's', '\0',
  /*  4527 - "testOnly.mabelsLikeBalloons" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'm', 'a', 'b', 'e', 'l', 's', 'L', 'i', 'k', 'e', 'B', 'a', 'l', 'l', 'o', 'o', 'n', 's', '\0',
  /*  4555 - "testOnly.mabelsLikeLabeledBalloons" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'm', 'a', 'b', 'e', 'l', 's', 'L', 'i', 'k', 'e', 'L', 'a', 'b', 'e', 'l', 'e', 'd', 'B', 'a', 'l', 'l', 'o', 'o', 'n', 's', '\0',
  /*  4590 - "testOnly.meaningOfLife" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'm', 'e', 'a', 'n', 'i', 'n', 'g', 'O', 'f', 'L', 'i', 'f', 'e', '\0',
  /*  4613 - "testOnly.mirrorTime" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'm', 'i', 'r', 'r', 'o', 'r', 'T', 'i', 'm', 'e', '\0',
  /*  4633 - "testOnly.mirrorTimeNanos" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'm', 'i', 'r', 'r', 'o', 'r', 'T', 'i', 'm', 'e', 'N', 'a', 'n', 'o', 's', '\0',
  /*  4658 - "testOnly.mirrorsForLabeledBools" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'm', 'i', 'r', 'r', 'o', 'r', 's', 'F', 'o', 'r', 'L', 'a', 'b', 'e', 'l', 'e', 'd', 'B', 'o', 'o', 'l', 's', '\0',
  /*  4690 - "testOnly.onePingOneBool" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'o', 'n', 'e', 'P', 'i', 'n', 'g', 'O', 'n', 'e', 'B', 'o', 'o', 'l', '\0',
  /*  4714 - "testOnly.whatADate" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'w', 'h', 'a', 't', 'A', 'D', 'a', 't', 'e', '\0',
  /*  4733 - "testOnly.whatIdIt" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'w', 'h', 'a', 't', 'I', 'd', 'I', 't', '\0',
  /*  4751 - "testOnly.whatTimeIsIt" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'w', 'h', 'a', 't', 'T', 'i', 'm', 'e', 'I', 's', 'I', 't', '\0',
  /*  4773 - "testOnlyIpc.aBool" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'a', 'B', 'o', 'o', 'l', '\0',
  /*  4791 - "testOnlyIpc.aCounter" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'a', 'C', 'o', 'u', 'n', 't', 'e', 'r', '\0',
  /*  4812 - "testOnlyIpc.aCustomDist" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'a', 'C', 'u', 's', 't', 'o', 'm', 'D', 'i', 's', 't', '\0',
  /*  4836 - "testOnlyIpc.aDate" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'a', 'D', 'a', 't', 'e', '\0',
  /*  4854 - "testOnlyIpc.aLabeledCounter" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'a', 'L', 'a', 'b', 'e', 'l', 'e', 'd', 'C', 'o', 'u', 'n', 't', 'e', 'r', '\0',
  /*  4882 - "testOnlyIpc.aMemoryDist" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'a', 'M', 'e', 'm', 'o', 'r', 'y', 'D', 'i', 's', 't', '\0',
  /*  4906 - "testOnlyIpc.aQuantity" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'a', 'Q', 'u', 'a', 'n', 't', 'i', 't', 'y', '\0',
  /*  4928 - "testOnlyIpc.aString" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'a', 'S', 't', 'r', 'i', 'n', 'g', '\0',
  /*  4948 - "testOnlyIpc.aStringList" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'a', 'S', 't', 'r', 'i', 'n', 'g', 'L', 'i', 's', 't', '\0',
  /*  4972 - "testOnlyIpc.aTimingDist" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'a', 'T', 'i', 'm', 'i', 'n', 'g', 'D', 'i', 's', 't', '\0',
  /*  4996 - "testOnlyIpc.aUrl" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'a', 'U', 'r', 'l', '\0',
  /*  5013 - "testOnlyIpc.aUuid" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'a', 'U', 'u', 'i', 'd', '\0',
  /*  5031 - "testOnlyIpc.anEvent" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'a', 'n', 'E', 'v', 'e', 'n', 't', '\0',
  /*  5051 - "testOnlyIpc.anExternalDenominator" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'a', 'n', 'E', 'x', 't', 'e', 'r', 'n', 'a', 'l', 'D', 'e', 'n', 'o', 'm', 'i', 'n', 'a', 't', 'o', 'r', '\0',
  /*  5085 - "testOnlyIpc.anotherLabeledCounter" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'a', 'n', 'o', 't', 'h', 'e', 'r', 'L', 'a', 'b', 'e', 'l', 'e', 'd', 'C', 'o', 'u', 'n', 't', 'e', 'r', '\0',
  /*  5119 - "testOnlyIpc.eventWithExtra" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'e', 'v', 'e', 'n', 't', 'W', 'i', 't', 'h', 'E', 'x', 't', 'r', 'a', '\0',
  /*  5146 - "testOnlyIpc.irate" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'i', 'r', 'a', 't', 'e', '\0',
  /*  5164 - "testOnlyIpc.noExtraEvent" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'n', 'o', 'E', 'x', 't', 'r', 'a', 'E', 'v', 'e', 'n', 't', '\0',
  /*  5189 - "testOnlyIpc.rateWithExternalDenominator" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'r', 'a', 't', 'e', 'W', 'i', 't', 'h', 'E', 'x', 't', 'e', 'r', 'n', 'a', 'l', 'D', 'e', 'n', 'o', 'm', 'i', 'n', 'a', 't', 'o', 'r', '\0',
  /*  5229 - "testOnlyJog.aCounter" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'J', 'o', 'g', '.', 'a', 'C', 'o', 'u', 'n', 't', 'e', 'r', '\0',
  /*  5250 - "testOnlyJog.anEvent" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'J', 'o', 'g', '.', 'a', 'n', 'E', 'v', 'e', 'n', 't', '\0',
  /*  5270 - "nimbusEvents.enrollFailed" */ 'n', 'i', 'm', 'b', 'u', 's', 'E', 'v', 'e', 'n', 't', 's', '.', 'e', 'n', 'r', 'o', 'l', 'l', 'F', 'a', 'i', 'l', 'e', 'd', '\0',
  /*  5296 - "nimbusEvents.enrollment" */ 'n', 'i', 'm', 'b', 'u', 's', 'E', 'v', 'e', 'n', 't', 's', '.', 'e', 'n', 'r', 'o', 'l', 'l', 'm', 'e', 'n', 't', '\0',
  /*  5320 - "nimbusEvents.exposure" */ 'n', 'i', 'm', 'b', 'u', 's', 'E', 'v', 'e', 'n', 't', 's', '.', 'e', 'x', 'p', 'o', 's', 'u', 'r', 'e', '\0',
  /*  5342 - "nimbusEvents.unenrollFailed" */ 'n', 'i', 'm', 'b', 'u', 's', 'E', 'v', 'e', 'n', 't', 's', '.', 'u', 'n', 'e', 'n', 'r', 'o', 'l', 'l', 'F', 'a', 'i', 'l', 'e', 'd', '\0',
  /*  5370 - "nimbusEvents.unenrollment" */ 'n', 'i', 'm', 'b', 'u', 's', 'E', 'v', 'e', 'n', 't', 's', '.', 'u', 'n', 'e', 'n', 'r', 'o', 'l', 'l', 'm', 'e', 'n', 't', '\0',
  /*  5396 - "nimbusEvents.validationFailed" */ 'n', 'i', 'm', 'b', 'u', 's', 'E', 'v', 'e', 'n', 't', 's', '.', 'v', 'a', 'l', 'i', 'd', 'a', 't', 'i', 'o', 'n', 'F', 'a', 'i', 'l', 'e', 'd', '\0',
  /*  5426 - "pdfjs.buttons" */ 'p', 'd', 'f', 'j', 's', '.', 'b', 'u', 't', 't', 'o', 'n', 's', '\0',
  /*  5440 - "pdfjs.editing" */ 'p', 'd', 'f', 'j', 's', '.', 'e', 'd', 'i', 't', 'i', 'n', 'g', '\0',
  /*  5454 - "pdfjs.timeToView" */ 'p', 'd', 'f', 'j', 's', '.', 't', 'i', 'm', 'e', 'T', 'o', 'V', 'i', 'e', 'w', '\0',
  /*  5471 - "pdfjs.used" */ 'p', 'd', 'f', 'j', 's', '.', 'u', 's', 'e', 'd', '\0',
  /*  5482 - "power.cpuTimeBogusValues" */ 'p', 'o', 'w', 'e', 'r', '.', 'c', 'p', 'u', 'T', 'i', 'm', 'e', 'B', 'o', 'g', 'u', 's', 'V', 'a', 'l', 'u', 'e', 's', '\0',
  /*  5507 - "power.cpuTimePerProcessTypeMs" */ 'p', 'o', 'w', 'e', 'r', '.', 'c', 'p', 'u', 'T', 'i', 'm', 'e', 'P', 'e', 'r', 'P', 'r', 'o', 'c', 'e', 's', 's', 'T', 'y', 'p', 'e', 'M', 's', '\0',
  /*  5537 - "power.cpuTimePerTrackerTypeMs" */ 'p', 'o', 'w', 'e', 'r', '.', 'c', 'p', 'u', 'T', 'i', 'm', 'e', 'P', 'e', 'r', 'T', 'r', 'a', 'c', 'k', 'e', 'r', 'T', 'y', 'p', 'e', 'M', 's', '\0',
  /*  5567 - "power.gpuTimeBogusValues" */ 'p', 'o', 'w', 'e', 'r', '.', 'g', 'p', 'u', 'T', 'i', 'm', 'e', 'B', 'o', 'g', 'u', 's', 'V', 'a', 'l', 'u', 'e', 's', '\0',
  /*  5592 - "power.gpuTimePerProcessTypeMs" */ 'p', 'o', 'w', 'e', 'r', '.', 'g', 'p', 'u', 'T', 'i', 'm', 'e', 'P', 'e', 'r', 'P', 'r', 'o', 'c', 'e', 's', 's', 'T', 'y', 'p', 'e', 'M', 's', '\0',
  /*  5622 - "power.totalCpuTimeMs" */ 'p', 'o', 'w', 'e', 'r', '.', 't', 'o', 't', 'a', 'l', 'C', 'p', 'u', 'T', 'i', 'm', 'e', 'M', 's', '\0',
  /*  5643 - "power.totalGpuTimeMs" */ 'p', 'o', 'w', 'e', 'r', '.', 't', 'o', 't', 'a', 'l', 'G', 'p', 'u', 'T', 'i', 'm', 'e', 'M', 's', '\0',
  /*  5664 - "power.totalThreadWakeups" */ 'p', 'o', 'w', 'e', 'r', '.', 't', 'o', 't', 'a', 'l', 'T', 'h', 'r', 'e', 'a', 'd', 'W', 'a', 'k', 'e', 'u', 'p', 's', '\0',
  /*  5689 - "power.wakeupsPerProcessType" */ 'p', 'o', 'w', 'e', 'r', '.', 'w', 'a', 'k', 'e', 'u', 'p', 's', 'P', 'e', 'r', 'P', 'r', 'o', 'c', 'e', 's', 's', 'T', 'y', 'p', 'e', '\0',
  /*  5717 - "powerBattery.percentageWhenUserActive" */ 'p', 'o', 'w', 'e', 'r', 'B', 'a', 't', 't', 'e', 'r', 'y', '.', 'p', 'e', 'r', 'c', 'e', 'n', 't', 'a', 'g', 'e', 'W', 'h', 'e', 'n', 'U', 's', 'e', 'r', 'A', 'c', 't', 'i', 'v', 'e', '\0',
  /*  5755 - "powerCpuMsPerThread.contentBackground" */ 'p', 'o', 'w', 'e', 'r', 'C', 'p', 'u', 'M', 's', 'P', 'e', 'r', 'T', 'h', 'r', 'e', 'a', 'd', '.', 'c', 'o', 'n', 't', 'e', 'n', 't', 'B', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', '\0',
  /*  5793 - "powerCpuMsPerThread.contentForeground" */ 'p', 'o', 'w', 'e', 'r', 'C', 'p', 'u', 'M', 's', 'P', 'e', 'r', 'T', 'h', 'r', 'e', 'a', 'd', '.', 'c', 'o', 'n', 't', 'e', 'n', 't', 'F', 'o', 'r', 'e', 'g', 'r', 'o', 'u', 'n', 'd', '\0',
  /*  5831 - "powerCpuMsPerThread.gpuProcess" */ 'p', 'o', 'w', 'e', 'r', 'C', 'p', 'u', 'M', 's', 'P', 'e', 'r', 'T', 'h', 'r', 'e', 'a', 'd', '.', 'g', 'p', 'u', 'P', 'r', 'o', 'c', 'e', 's', 's', '\0',
  /*  5862 - "powerCpuMsPerThread.parentActive" */ 'p', 'o', 'w', 'e', 'r', 'C', 'p', 'u', 'M', 's', 'P', 'e', 'r', 'T', 'h', 'r', 'e', 'a', 'd', '.', 'p', 'a', 'r', 'e', 'n', 't', 'A', 'c', 't', 'i', 'v', 'e', '\0',
  /*  5895 - "powerCpuMsPerThread.parentInactive" */ 'p', 'o', 'w', 'e', 'r', 'C', 'p', 'u', 'M', 's', 'P', 'e', 'r', 'T', 'h', 'r', 'e', 'a', 'd', '.', 'p', 'a', 'r', 'e', 'n', 't', 'I', 'n', 'a', 'c', 't', 'i', 'v', 'e', '\0',
  /*  5930 - "powerWakeupsPerThread.contentBackground" */ 'p', 'o', 'w', 'e', 'r', 'W', 'a', 'k', 'e', 'u', 'p', 's', 'P', 'e', 'r', 'T', 'h', 'r', 'e', 'a', 'd', '.', 'c', 'o', 'n', 't', 'e', 'n', 't', 'B', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', '\0',
  /*  5970 - "powerWakeupsPerThread.contentForeground" */ 'p', 'o', 'w', 'e', 'r', 'W', 'a', 'k', 'e', 'u', 'p', 's', 'P', 'e', 'r', 'T', 'h', 'r', 'e', 'a', 'd', '.', 'c', 'o', 'n', 't', 'e', 'n', 't', 'F', 'o', 'r', 'e', 'g', 'r', 'o', 'u', 'n', 'd', '\0',
  /*  6010 - "powerWakeupsPerThread.gpuProcess" */ 'p', 'o', 'w', 'e', 'r', 'W', 'a', 'k', 'e', 'u', 'p', 's', 'P', 'e', 'r', 'T', 'h', 'r', 'e', 'a', 'd', '.', 'g', 'p', 'u', 'P', 'r', 'o', 'c', 'e', 's', 's', '\0',
  /*  6043 - "powerWakeupsPerThread.parentActive" */ 'p', 'o', 'w', 'e', 'r', 'W', 'a', 'k', 'e', 'u', 'p', 's', 'P', 'e', 'r', 'T', 'h', 'r', 'e', 'a', 'd', '.', 'p', 'a', 'r', 'e', 'n', 't', 'A', 'c', 't', 'i', 'v', 'e', '\0',
  /*  6078 - "powerWakeupsPerThread.parentInactive" */ 'p', 'o', 'w', 'e', 'r', 'W', 'a', 'k', 'e', 'u', 'p', 's', 'P', 'e', 'r', 'T', 'h', 'r', 'e', 'a', 'd', '.', 'p', 'a', 'r', 'e', 'n', 't', 'I', 'n', 'a', 'c', 't', 'i', 'v', 'e', '\0',
  /*  6115 - "searchEngineDefault.changed" */ 's', 'e', 'a', 'r', 'c', 'h', 'E', 'n', 'g', 'i', 'n', 'e', 'D', 'e', 'f', 'a', 'u', 'l', 't', '.', 'c', 'h', 'a', 'n', 'g', 'e', 'd', '\0',
  /*  6143 - "searchEngineDefault.displayName" */ 's', 'e', 'a', 'r', 'c', 'h', 'E', 'n', 'g', 'i', 'n', 'e', 'D', 'e', 'f', 'a', 'u', 'l', 't', '.', 'd', 'i', 's', 'p', 'l', 'a', 'y', 'N', 'a', 'm', 'e', '\0',
  /*  6175 - "searchEngineDefault.engineId" */ 's', 'e', 'a', 'r', 'c', 'h', 'E', 'n', 'g', 'i', 'n', 'e', 'D', 'e', 'f', 'a', 'u', 'l', 't', '.', 'e', 'n', 'g', 'i', 'n', 'e', 'I', 'd', '\0',
  /*  6204 - "searchEngineDefault.loadPath" */ 's', 'e', 'a', 'r', 'c', 'h', 'E', 'n', 'g', 'i', 'n', 'e', 'D', 'e', 'f', 'a', 'u', 'l', 't', '.', 'l', 'o', 'a', 'd', 'P', 'a', 't', 'h', '\0',
  /*  6233 - "searchEngineDefault.submissionUrl" */ 's', 'e', 'a', 'r', 'c', 'h', 'E', 'n', 'g', 'i', 'n', 'e', 'D', 'e', 'f', 'a', 'u', 'l', 't', '.', 's', 'u', 'b', 'm', 'i', 's', 's', 'i', 'o', 'n', 'U', 'r', 'l', '\0',
  /*  6267 - "searchEngineDefault.verified" */ 's', 'e', 'a', 'r', 'c', 'h', 'E', 'n', 'g', 'i', 'n', 'e', 'D', 'e', 'f', 'a', 'u', 'l', 't', '.', 'v', 'e', 'r', 'i', 'f', 'i', 'e', 'd', '\0',
  /*  6296 - "searchEnginePrivate.changed" */ 's', 'e', 'a', 'r', 'c', 'h', 'E', 'n', 'g', 'i', 'n', 'e', 'P', 'r', 'i', 'v', 'a', 't', 'e', '.', 'c', 'h', 'a', 'n', 'g', 'e', 'd', '\0',
  /*  6324 - "searchEnginePrivate.displayName" */ 's', 'e', 'a', 'r', 'c', 'h', 'E', 'n', 'g', 'i', 'n', 'e', 'P', 'r', 'i', 'v', 'a', 't', 'e', '.', 'd', 'i', 's', 'p', 'l', 'a', 'y', 'N', 'a', 'm', 'e', '\0',
  /*  6356 - "searchEnginePrivate.engineId" */ 's', 'e', 'a', 'r', 'c', 'h', 'E', 'n', 'g', 'i', 'n', 'e', 'P', 'r', 'i', 'v', 'a', 't', 'e', '.', 'e', 'n', 'g', 'i', 'n', 'e', 'I', 'd', '\0',
  /*  6385 - "searchEnginePrivate.loadPath" */ 's', 'e', 'a', 'r', 'c', 'h', 'E', 'n', 'g', 'i', 'n', 'e', 'P', 'r', 'i', 'v', 'a', 't', 'e', '.', 'l', 'o', 'a', 'd', 'P', 'a', 't', 'h', '\0',
  /*  6414 - "searchEnginePrivate.submissionUrl" */ 's', 'e', 'a', 'r', 'c', 'h', 'E', 'n', 'g', 'i', 'n', 'e', 'P', 'r', 'i', 'v', 'a', 't', 'e', '.', 's', 'u', 'b', 'm', 'i', 's', 's', 'i', 'o', 'n', 'U', 'r', 'l', '\0',
  /*  6448 - "searchEnginePrivate.verified" */ 's', 'e', 'a', 'r', 'c', 'h', 'E', 'n', 'g', 'i', 'n', 'e', 'P', 'r', 'i', 'v', 'a', 't', 'e', '.', 'v', 'e', 'r', 'i', 'f', 'i', 'e', 'd', '\0',
  /*  6477 - "dap.reportGenerationStatus" */ 'd', 'a', 'p', '.', 'r', 'e', 'p', 'o', 'r', 't', 'G', 'e', 'n', 'e', 'r', 'a', 't', 'i', 'o', 'n', 'S', 't', 'a', 't', 'u', 's', '\0',
  /*  6504 - "dap.uploadStatus" */ 'd', 'a', 'p', '.', 'u', 'p', 'l', 'o', 'a', 'd', 'S', 't', 'a', 't', 'u', 's', '\0',
  /*  6521 - "legacyTelemetry.clientId" */ 'l', 'e', 'g', 'a', 'c', 'y', 'T', 'e', 'l', 'e', 'm', 'e', 't', 'r', 'y', '.', 'c', 'l', 'i', 'e', 'n', 't', 'I', 'd', '\0',
  /*  6546 - "firstStartup.elapsed" */ 'f', 'i', 'r', 's', 't', 'S', 't', 'a', 'r', 't', 'u', 'p', '.', 'e', 'l', 'a', 'p', 's', 'e', 'd', '\0',
  /*  6567 - "firstStartup.statusCode" */ 'f', 'i', 'r', 's', 't', 'S', 't', 'a', 'r', 't', 'u', 'p', '.', 's', 't', 'a', 't', 'u', 's', 'C', 'o', 'd', 'e', '\0',
  /*  6591 - "update.autoDownload" */ 'u', 'p', 'd', 'a', 't', 'e', '.', 'a', 'u', 't', 'o', 'D', 'o', 'w', 'n', 'l', 'o', 'a', 'd', '\0',
  /*  6611 - "update.backgroundUpdate" */ 'u', 'p', 'd', 'a', 't', 'e', '.', 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'U', 'p', 'd', 'a', 't', 'e', '\0',
  /*  6635 - "update.canUsuallyApplyUpdates" */ 'u', 'p', 'd', 'a', 't', 'e', '.', 'c', 'a', 'n', 'U', 's', 'u', 'a', 'l', 'l', 'y', 'A', 'p', 'p', 'l', 'y', 'U', 'p', 'd', 'a', 't', 'e', 's', '\0',
  /*  6665 - "update.canUsuallyCheckForUpdates" */ 'u', 'p', 'd', 'a', 't', 'e', '.', 'c', 'a', 'n', 'U', 's', 'u', 'a', 'l', 'l', 'y', 'C', 'h', 'e', 'c', 'k', 'F', 'o', 'r', 'U', 'p', 'd', 'a', 't', 'e', 's', '\0',
  /*  6698 - "update.canUsuallyStageUpdates" */ 'u', 'p', 'd', 'a', 't', 'e', '.', 'c', 'a', 'n', 'U', 's', 'u', 'a', 'l', 'l', 'y', 'S', 't', 'a', 'g', 'e', 'U', 'p', 'd', 'a', 't', 'e', 's', '\0',
  /*  6728 - "update.canUsuallyUseBits" */ 'u', 'p', 'd', 'a', 't', 'e', '.', 'c', 'a', 'n', 'U', 's', 'u', 'a', 'l', 'l', 'y', 'U', 's', 'e', 'B', 'i', 't', 's', '\0',
  /*  6753 - "update.channel" */ 'u', 'p', 'd', 'a', 't', 'e', '.', 'c', 'h', 'a', 'n', 'n', 'e', 'l', '\0',
  /*  6768 - "update.enabled" */ 'u', 'p', 'd', 'a', 't', 'e', '.', 'e', 'n', 'a', 'b', 'l', 'e', 'd', '\0',
  /*  6783 - "update.serviceEnabled" */ 'u', 'p', 'd', 'a', 't', 'e', '.', 's', 'e', 'r', 'v', 'i', 'c', 'e', 'E', 'n', 'a', 'b', 'l', 'e', 'd', '\0',
  /*  6805 - "startup.isRestoredByMacos" */ 's', 't', 'a', 'r', 't', 'u', 'p', '.', 'i', 's', 'R', 'e', 's', 't', 'o', 'r', 'e', 'd', 'B', 'y', 'M', 'a', 'c', 'o', 's', '\0',
  /*  6831 - "timerThread.timersFiredPerWakeup" */ 't', 'i', 'm', 'e', 'r', 'T', 'h', 'r', 'e', 'a', 'd', '.', 't', 'i', 'm', 'e', 'r', 's', 'F', 'i', 'r', 'e', 'd', 'P', 'e', 'r', 'W', 'a', 'k', 'e', 'u', 'p', '\0',
};


static_assert(sizeof(gMetricStringTable) < 4294967296, "Metric string table is too large.");

const metric_entry_t sMetricByNameLookupEntries[] = {
  4611686894600721952ull,
  4611686374909675677ull,
  576461387958587595ull,
  5188147500875256566ull,
  2305843722178269861ull,
  5188147664084014753ull,
  3458765514547927463ull,
  4035225566771677084ull,
  2305844052890753685ull,
  4611686237470721210ull,
  2882304792309275233ull,
  5188147689853818746ull,
  2305844027120949769ull,
  6341068571690403691ull,
  5188147140098001140ull,
  4611686636902682746ull,
  8070451223737668146ull,
  5764608291833385915ull,
  5188147625429308833ull,
  2882304727884765396ull,
  2305844048595786367ull,
  2882304706409928764ull,
  6917529585986834120ull,
  1729382961284911741ull,
  4035225437922657226ull,
  5188147299011792430ull,
  2305843704998400594ull,
  4611686233175753887ull,
  4035226064987886722ull,
  6917529607461670792ull,
  3458765192425378286ull,
  5188147157277870436ull,
  5764607763552404805ull,
  5188147152982903121ull,
  6341068524445762954ull,
  5188147148687935806ull,
  3458764724273939584ull,
  4611686628312748096ull,
  7493990664707774037ull,
  4035225665555925433ull,
  2305844014236047807ull,
  10376294516419205390ull,
  7493990140721760432ull,
  2882303787286921387ull,
  6917529598871736121ull,
  6341068537330664974ull,
  2305843030688530570ull,
  2305843146652648235ull,
  5188147599659504946ull,
  3458764917547469277ull,
  5188147423565844791ull,
  1152921513196781604ull,
  8646911877256843247ull,
  3458764921842436611ull,
  8646911830012202611ull,
  3458765003446815994ull,
  4035226223901677720ull,
  1152921551851487565ull,
  4611686886010787318ull,
  6341068563100469012ull,
  4035226043513050111ull,
  6917529358353565731ull,
  2882303838826529324ull,
  576460756598390784ull,
  2305843133767746283ull,
  2305843421530556967ull,
  4035226069282854038ull,
  6341068545920599648ull,
  5188147333371530988ull,
  4035226086462723322ull,
  3458764711389037617ull,
  4035225356318278248ull,
  4035225429332722599ull,
  8646911911616581792ull,
  3458764934727338612ull,
  5188147685558851410ull,
  5188147002659046681ull,
  6917529336878729157ull,
  5188147161572837758ull,
  2882303847416463954ull,
  4035225450807559165ull,
  9223372771294188306ull,
  6341069065611646021ull,
  4035226198131873763ull,
  5188147144392968473ull,
  4611686860240983391ull,
  2305843528904740332ull,
  3458765252554920746ull,
  10376294297375871876ull,
  7493990501499015884ull,
  576461499627737940ull,
  8646911834307169920ull,
  2305843425825524298ull,
  1729383017119486869ull,
  2305843060753301877ull,
  8070451206557798859ull,
  2305843597624217556ull,
  4611686890305754635ull,
  9223372603790462738ull,
  4035225420742787960ull,
  5188147698443753406ull,
  6341068533035697632ull,
  4035225442217624538ull,
  4611686877420852671ull,
  4611686864535950698ull,
  4035225772930108823ull,
  4611686224585819234ull,
  9799833437698265369ull,
  2305843494545001679ull,
  6341068550215566985ull,
  5764607759257437490ull,
  4035225339138408990ull,
  6917529332583761834ull,
  1152921543261552888ull,
  6341068567395436354ull,
  2305843211077157959ull,
  4035225699915664106ull,
  4035225399267951388ull,
  6341068554510534330ull,
  4035225364908212875ull,
  8646911971746124313ull,
  5188147676968916743ull,
  4035225330548474332ull,
  5188147621134341507ull,
  4035225455102526479ull,
  2305843065048269209ull,
  8070451202262831535ull,
  2305843026393563239ull,
  6917529345468663782ull,
  9223372612380397408ull,
  2305843468775197679ull,
  3458764977677011990ull,
  576460782368194759ull,
  9223372676804907237ull,
  5188147651199112761ull,
  1152922204686520938ull,
  3458765067871325856ull,
  6917529354058598419ull,
  2305843490250034347ull,
  3458764956202175294ull,
  4035226077872788680ull,
  5188147286126890445ull,
  5188147672673949414ull,
  1152922045772729960ull,
  4035226073577821360ull,
  2882304723589798068ull,
  5188147281831923116ull,
  6917529736310690447ull,
  3458764908957534614ull,
  9223372633855234050ull,
  7493990827916532399ull,
  2882304504546464576ull,
  10376294490649401433ull,
  6917529349763631100ull,
  3458764659849429840ull,
  1152922230456324836ull,
  5188146994069112018ull,
  2882304732179732721ull,
  9799833450583167350ull,
  1729382269795172429ull,
  5188147436450746768ull,
  5188147603954472256ull,
  5188147659789047419ull,
  4035225425037755277ull,
  3458764990561913990ull,
  2882304392877314229ull,
  4035226052102984748ull,
  9799833433403298044ull,
  3458764951907207955ull,
  2882304714999863419ull,
  2305843631983956107ull,
  3458764573950083514ull,
  4035225433627689912ull,
  3458764969087077310ull,
  4035225459397493791ull,
  4611686812996342893ull,
  2305844031415917098ull,
  2305843103702975094ull,
  2305843460185262991ull,
  7493990145016727761ull,
  2882303843121496644ull,
  4611686735686931127ull,
  4035225386383049439ull,
  3458764556770214177ull,
  7493990617463133518ull,
  6917529779260363628ull,
  2305843125177811661ull,
  4035225407857886012ull,
  576460786663162080ull,
  6341068541625632316ull,
  2305843546084609626ull,
  2305843503134936359ull,
  2305843116587877036ull,
  8070451030464138570ull,
  6341068558805501670ull,
  1729383249047722361ull,
  8646911967451156997ull,
  6917529375533434996ull,
  6917529341173696471ull,
  3458764943317273282ull,
  4035225734275402810ull,
  2882304697819994111ull,
  4035225369203180191ull,
  2882304702114961439ull,
  4035226030628148135ull,
  3458764986266946655ull,
  4611686632607715414ull,
  6917529628936507413ull,
  2305844035710884424ull,
  2305843455890295655ull,
  4035225394972984074ull,
  5188146998364079349ull,
  5188147694148786075ull,
  8070451034759105904ull,
  2305843159537550174ull,
  2305844044300819056ull,
  5188147681263884074ull,
  2882304294093065800ull,
  5188147543824929757ull,
  4611686624017780779ull,
  6917529611756638128ull,
  5188147754278328653ull,
  4035225377793114811ull,
  2305844022825982443ull,
  3458765510252960146ull,
  6917529371238467674ull,
  2305843434415458976ull,
  2305844018531015123ull,
  6917529366943500361ull,
  5188147634019243480ull,
  6917529362648533047ull,
  5188147427860812119ull,
  5188147668378982087ull,
  4035226090757690644ull,
  10952755075449099290ull,
  2882304740769667376ull,
  4035225446512591850ull,
  6917529379828402312ull,
  6341068528740730294ull,
  4035226082167755998ull,
  576460821022900743ull,
  5188147758573295976ull,
  6341068520150795627ull,
  6917529551627095564ull
};



Maybe<uint32_t>
MetricByNameLookup(const nsACString& aKey)
{
  static const uint8_t BASES[] = {
       0,   0,   1,   0,   1,   3,   0,   0,   0,   1,   0,   0,   0,   1,   0,   0,
       0,   0,   1,   0,   0,   0,   2,   1,   1,   3,   0,   0,   2,   1,   1,   0,
       1,   1,   1,   2,   0,   1,   0,   1,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   3,   0,   0,   2,   0,   0,   0,   0,   0,   0,   0,   1,
       1,   0,   0,   0,   0,   0,   0,   0,   0,   2,   1,   0,   0,   0,   2,   0,
       0,   1,   3,   3,   1,   4,   0,   0,   0,   2,   0,   0,   1,   0,   0,   0,
       0,   0,   0,   1,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   3,   0,
       0,   2,   0,   0,   1,   0,   1,   2,   0,   2,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   1,   3,   3,   0,   0,   1,   1,   0,   0,   0,   0,   1,   1,
       1,   0,   0,   4,   0,   0,   0,   2,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   1,   0,   1,   2,
       0,   0,   0,   3,   3,   0,   0,   0,   1,   0,   0,   0,   0,   0,   0,   1,
       1,   0,   0,   0,   0,   0,   3,   1,   0,   0,   0,   0,   2,   0,   0,   3,
       0,   0,   0,   0,   0,   0,   1,   1,   0,   1,   0,   2,   2,   0,   2,   0,
       0,   0,   1,   1,   4,   3,   0,   0,   0,   0,   0,   1,   1,   0,   1,   2,
       4,   4,   0,   0,   0,   1,   1,   8,   0,   0,   0,   0,   0,   0,   3,   0,
       0,   1,   0,   1,   0,   0,   0,   0,   0,   1,   1,   2,   0,   4,   1,   3,
       1,   0,   0,   3,   0,   0,   0,   3,   1,   4,   0,   0,   0,   5,   0,   3,
       0,   2,   0,   0,   6,   0,   6,   0,   0,   0,   1,   0,   1,   3,   0,   2,
       1,   2,   0,   0,   0,   4,   0,   0,   0,   3,   7,   0,   0,   3,   0,   0,
       0,   0,   0,  12,   2,   0,   6,   0,   0,   0,   0,   1,   0,   0,   0,   0,
       0,   1,   1,   1,   0,   0,   0,   0,   3,   0,   0,   3,   2,   6,   2,   4,
       2,   4,   0,   0,   0,   1,   0,   2,   1,   0,   2,   7,   0,   0,   7,   0,
       2,  11,   0,   0,   0,   0,   9,   6,   2,   1,   0,   6,   3,   0,   0,   0,
       4,   1,   8,   2,   0,   8,   1,   0,   0,   0,   0,   0,   1,   8,   9,   0,
       1,   0,   0,   0,   1,   4,   1,   0,   9,   0,   0,   0,   6,   2,   0,   0,
       0,   0,   1,   0,   0,   0,   0,   5,   0,   1,   0,   7,   0,   0,   6,  15,
       0,   1,   0,   0,   0,   0,   0,   3,   0,   0,   0,   2,   0,   0,   0,   0,
      11,   1,  10,   0,  21,  13,   0,  13,   0,   0,  12,   0,  10,   5,   0,  21,
       0,   0,   0,   0,  10,   0,   4,   0,   7,   0,   2,   0,   0,   2,  17,   0,
       0,   0,   3,   0,   0,   0,   0,   0,   7,   0,   2,   0,   3,   3,  16,   0,
      10,   0,  10,  55,  18,   0,   0,  34,   0,  37,   0,   0,   0,   0, 122,   0,
  };
  

  const char* bytes = aKey.BeginReading();
  size_t length = aKey.Length();
  auto& entry = mozilla::perfecthash::Lookup(bytes, length, BASES,
                                             sMetricByNameLookupEntries);
  return metric_result_check(aKey, entry);
}


/**
 * Get a category's name from the string table.
 */
const char* GetCategoryName(category_entry_t entry) {
  MOZ_ASSERT(entry < sizeof(gCategoryStringTable), "Entry identifier offset larger than string table");
  return &gCategoryStringTable[entry];
}

/**
 * Get a metric's identifier from the string table.
 */
const char* GetMetricIdentifier(metric_entry_t entry) {
  uint32_t offset = GLEAN_OFFSET(entry);
  MOZ_ASSERT(offset < sizeof(gMetricStringTable), "Entry identifier offset larger than string table");
  return &gMetricStringTable[offset];
}

/**
 * Check that the found entry is pointing to the right key
 * and return it.
 * Or return `Nothing()` if the entry was not found.
 */
static Maybe<uint32_t> category_result_check(const nsACString& aKey, category_entry_t entry) {
  if (MOZ_UNLIKELY(entry > sizeof(gCategoryStringTable))) {
    return Nothing();
  }
  if (aKey.EqualsASCII(gCategoryStringTable + entry)) {
    return Some(entry);
  }
  return Nothing();
}

/**
 * Check if the found entry index is pointing to the right key
 * and return the corresponding metric ID.
 * Or return `Nothing()` if the entry was not found.
 */
static Maybe<uint32_t> metric_result_check(const nsACString& aKey, uint64_t entry) {
  uint32_t metricId = entry >> GLEAN_INDEX_BITS;
  uint32_t offset = GLEAN_OFFSET(entry);

  if (offset > sizeof(gMetricStringTable)) {
    return Nothing();
  }

  if (aKey.EqualsASCII(gMetricStringTable + offset)) {
    return Some(metricId);
  }

  return Nothing();
}


#undef GLEAN_INDEX_BITS
#undef GLEAN_ID_BITS
#undef GLEAN_TYPE_ID
#undef GLEAN_METRIC_ID
#undef GLEAN_OFFSET

} // namespace mozilla::glean
